=======
CHANGES
=======

4.0.0 (2017-04-22)
------------------

- Add support for Python 3.4, 3.5, and 3.6 and PyPy.

- Removed support for Python 2.6.

- Added ``tox.ini`` and manifest.

- Removed zope.app.testing dependency.

3.5.1 (2009-12-15)
------------------

- Added missing zcml namespace to the configure file.

3.5.0 (2009-12-15)
------------------

- Moved CheckDependency event handler and its tests into this package from
  its former place in zope.container.

3.4.0 (2007-10-23)
------------------

- Initial release independent of the main Zope tree.
